Module input

Module input 

Bounded, ordered input values for the host-to-session path.

Structs

InputId
Opaque identifier for one input submission.
InputRequest
Input bytes emitted by the core for the host’s transport adapter.
InputResult
Owned input result returned to a host after transport completion.

Enums

InputOutcome
Result reported by the transport adapter for one input request.