Bounded, ordered input values for the host-to-session path.
Structs
- InputId
- Opaque identifier for one input submission.
- Input
Request - Input bytes emitted by the core for the host’s transport adapter.
- Input
Result - Owned input result returned to a host after transport completion.
Enums
- Input
Outcome - Result reported by the transport adapter for one input request.